@@ -2,32 +2,9 @@
     importcertificatefromclipboardcommand.cpp
 
     This clipboard is part of Kleopatra, the KDE keymanager
-    Copyright (c) 2007 Klarälvdalens Datakonsult AB
+    SPDX-FileCopyrightText: 2007 Klarälvdalens Datakonsult AB
 
-    Kleopatra is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    Kleopatra is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
-
-    In addition, as a special exception, the copyright holders give
-    permission to link the code of this program with any edition of
-    the Qt library by Trolltech AS, Norway (or with modified versions
-    of Qt that use the same license as Qt), and distribute linked
-    combinations including the two.  You must obey the GNU General
-    Public License in all respects for all of the code used other than
-    Qt.  If you modify this clipboard, you may extend this exception to
-    your version of the clipboard, but you are not obligated to do so.  If
-    you do not wish to do so, delete this exception statement from
-    your version.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include <config-kleopatra.h>
@@ -44,9 +21,9 @@
 
 #include <KLocalizedString>
 
+#include <QApplication>
 #include <QByteArray>
 #include <QClipboard>
-#include <QApplication>
 #include <QMimeData>
 
 using namespace GpgME;
@@ -59,9 +36,10 @@ class ImportCertificateFromClipboardCommand::Private : public ImportCertificates
     {
         return static_cast<ImportCertificateFromClipboardCommand *>(q);
     }
+
 public:
     explicit Private(ImportCertificateFromClipboardCommand *qq, KeyListController *c);
-    ~Private();
+    ~Private() override;
 
     bool ensureHaveClipboard();
 
@@ -81,18 +59,18 @@ const ImportCertificateFromClipboardCommand::Private *ImportCertificateFromClipb
 ImportCertificateFromClipboardCommand::Private::Private(ImportCertificateFromClipboardCommand *qq, KeyListController *c)
     : ImportCertificatesCommand::Private(qq, c)
 {
-
 }
 
-ImportCertificateFromClipboardCommand::Private::~Private() {}
+ImportCertificateFromClipboardCommand::Private::~Private()
+{
+}
 
 // static
 bool ImportCertificateFromClipboardCommand::canImportCurrentClipboard()
 {
     if (const QClipboard *clip = QApplication::clipboard())
         if (const QMimeData *mime = clip->mimeData())
-            return mime->hasText()
-                   && mayBeAnyCertStoreType(classifyContent(mime->text().toUtf8()));
+            return mime->hasText() && mayBeAnyCertStoreType(classifyContent(mime->text().toUtf8()));
     return false;
 }
 
@@ -102,20 +80,19 @@ bool ImportCertificateFromClipboardCommand::canImportCurrentClipboard()
 ImportCertificateFromClipboardCommand::ImportCertificateFromClipboardCommand(KeyListController *p)
     : ImportCertificatesCommand(new Private(this, p))
 {
-
 }
 
 ImportCertificateFromClipboardCommand::ImportCertificateFromClipboardCommand(QAbstractItemView *v, KeyListController *p)
     : ImportCertificatesCommand(v, new Private(this, p))
 {
-
 }
 
-ImportCertificateFromClipboardCommand::~ImportCertificateFromClipboardCommand() {}
+ImportCertificateFromClipboardCommand::~ImportCertificateFromClipboardCommand()
+{
+}
 
 void ImportCertificateFromClipboardCommand::doStart()
 {
-
     if (!d->ensureHaveClipboard()) {
         Q_EMIT canceled();
         d->finished();
@@ -125,8 +102,7 @@ void ImportCertificateFromClipboardCommand::doStart()
     d->setWaitForMoreJobs(true);
     const unsigned int classification = classifyContent(d->input);
     if (!mayBeAnyCertStoreType(classification)) {
-        d->error(i18n("Clipboard contents do not look like a certificate."),
-                 i18n("Certificate Import Failed"));
+        d->error(i18n("Clipboard contents do not look like a certificate."), i18n("Certificate Import Failed"));
     } else {
         const GpgME::Protocol protocol = findProtocol(classification);
         if (protocol == GpgME::UnknownProtocol) {
@@ -151,3 +127,5 @@ bool ImportCertificateFromClipboardCommand::Private::ensureHaveClipboard()
 #undef q
 
 #endif // QT_NO_CLIPBOARD
+
+#include "moc_importcertificatefromclipboardcommand.cpp"
