@@ -184,6 +184,7 @@ bool importWasCanceled(const ImportResultData &r)
 
 ImportCertificatesCommand::Private::Private(ImportCertificatesCommand *qq, KeyListController *c)
     : Command::Private(qq, c)
+    , certificateListWasEmpty(KeyCache::instance()->keys().empty())
     , progressWindowTitle{i18nc("@title:window", "Importing Certificates")}
     , progressLabelText{i18n("Importing certificates... (this can take a while)")}
 {
@@ -252,6 +253,11 @@ void ImportCertificatesCommand::Private::setImportResultProxyModel(const std::ve
         })) {
         return;
     }
+
+    if (certificateListWasEmpty) {
+        return;
+    }
+
     q->addTemporaryView(i18nc("@title:tab", "Imported Certificates"), new ImportResultProxyModel(results), make_tooltip(results));
     if (QTreeView *const tv = qobject_cast<QTreeView *>(parentWidgetOrView())) {
         tv->expandAll();
@@ -485,11 +491,7 @@ void ImportCertificatesCommand::Private::showDetails(const std::vector<ImportRes
 {
     const auto singleOpenPGPImport = getSingleOpenPGPImport(res);
 
-    if (std::ranges::any_of(res, [](const auto &result) {
-            return result.result.numImported() > 0;
-        })) {
-        setImportResultProxyModel(res);
-    }
+    setImportResultProxyModel(res);
 
     if (!singleOpenPGPImport.isNull()) {
         if (showPleaseCertify(singleOpenPGPImport)) {
@@ -797,7 +799,7 @@ void ImportCertificatesCommand::Private::keyCacheUpdated()
 
 static ImportedGroup storeGroup(const KeyGroup &group, const QString &id, QWidget *parent)
 {
-    if (Kleo::any_of(group.keys(), [](const auto &key) {
+    if (std::ranges::any_of(group.keys(), [](const auto &key) {
             return !Kleo::keyHasEncrypt(key);
         })) {
         KMessageBox::information(parent,
@@ -920,6 +922,9 @@ void ImportCertificatesCommand::Private::startImport(GpgME::Protocol protocol,
     };
 
     job->setImportFilter(options.importFilter);
+#if QGPGME_IMPORT_JOB_SUPPORTS_IMPORT_OPTIONS
+    job->setImportOptions(options.importOptions);
+#endif
     job->setKeyOrigin(options.keyOrigin, options.keyOriginUrl);
     const GpgME::Error err = job->startLater(data);
     if (err.code()) {
