@@ -681,13 +681,14 @@ void KeyToCardCommand::Private::startDeleteSecretKeyLocally(Confirmation confirm
 
 void KeyToCardCommand::Private::deleteSecretKeyLocallyFinished(const GpgME::Error &err)
 {
+    ReaderStatus::mutableInstance()->updateStatus();
     if (err) {
         error(xi18nc("@info",
                      "<para>Failed to delete the copy of the key stored on this computer:</para><para><message>%1</message></para>",
                      Formatting::errorAsString(err)));
+    } else if (!err.isCanceled()) {
+        success(i18nc("@info", "Successfully deleted the copy of the key stored on this computer."));
     }
-    ReaderStatus::mutableInstance()->updateStatus();
-    success(i18nc("@info", "Successfully deleted the copy of the key stored on this computer."));
     finished();
 }
 
@@ -713,7 +714,7 @@ bool cardSupportsKeyAlgorithm(const std::shared_ptr<const Card> &card, const std
     if (card->appName() == OpenPGPCard::AppName) {
         const auto pgpCard = static_cast<const OpenPGPCard *>(card.get());
         const auto cardAlgos = pgpCard->supportedAlgorithms();
-        return Kleo::any_of(cardAlgos, [keyAlgo](const auto &algo) {
+        return std::ranges::any_of(cardAlgos, [keyAlgo](const auto &algo) {
             return (keyAlgo == algo.id) //
                 || (keyAlgo == OpenPGPCard::getAlgorithmName(algo.id, OpenPGPCard::pgpEncKeyRef()))
                 || (keyAlgo == OpenPGPCard::getAlgorithmName(algo.id, OpenPGPCard::pgpSigKeyRef()));
