@@ -52,12 +52,12 @@
 #include <QByteArray>
 #include <QDateTime>
 #include <QDir>
+#include <QFile>
 #include <QFileInfo>
 #include <QIODevice>
 #include <QLocale>
 #include <QMimeDatabase>
 #include <QStringList>
-#include <QTextDocument> // Qt::escape
 
 #include <algorithm>
 #include <sstream>
@@ -246,10 +246,10 @@ static QString renderKey(const Key &key)
         const QString text = QStringLiteral("%1 (%2)")
                                  .arg(Formatting::prettyNameAndEMail(key).toHtmlEscaped())
                                  .arg(Formatting::prettyID(QString::fromLocal8Bit(key.primaryFingerprint()).right(16).toLatin1().constData()));
-        return renderKeyLink(QLatin1String(key.primaryFingerprint()), text);
+        return renderKeyLink(QLatin1StringView(key.primaryFingerprint()), text);
     }
 
-    return renderKeyLink(QLatin1String(key.primaryFingerprint()), Formatting::prettyID(key.primaryFingerprint()));
+    return renderKeyLink(QLatin1StringView(key.primaryFingerprint()), Formatting::prettyID(key.primaryFingerprint()));
 }
 
 static QString renderKeyEMailOnlyNameAsFallback(const Key &key)
@@ -259,7 +259,7 @@ static QString renderKeyEMailOnlyNameAsFallback(const Key &key)
     }
     const QString email = Formatting::prettyEMail(key);
     const QString user = !email.isEmpty() ? email : Formatting::prettyName(key);
-    return renderKeyLink(QLatin1String(key.primaryFingerprint()), user);
+    return renderKeyLink(QLatin1StringView(key.primaryFingerprint()), user);
 }
 
 static QString formatDate(const QDateTime &dt)
@@ -464,7 +464,7 @@ static QString formatVerificationResultOverview(const VerificationResult &res, c
         text = i18n("<b>Valid signature by %1</b>", renderKeyEMailOnlyNameAsFallback(sigs[0].key()));
         if (info.conflicts())
             text += i18n("<br/><b>Warning:</b> The sender's mail address is not stored in the %1 used for signing.",
-                         renderKeyLink(QLatin1String(sigs[0].key().primaryFingerprint()), i18n("certificate")));
+                         renderKeyLink(QLatin1StringView(sigs[0].key().primaryFingerprint()), i18n("certificate")));
     } else {
         text = i18np("<b>Valid signature.</b>", "<b>%1 valid signatures.</b>", sigs.size());
         if (info.conflicts()) {
@@ -497,7 +497,7 @@ static QString formatSignature(const Signature &sig, const DecryptVerifyResult::
         return QString();
     }
 
-    const QString text = formatSigningInformation(sig) + QLatin1String("<br/>");
+    const QString text = formatSigningInformation(sig) + QLatin1StringView("<br/>");
     const Key key = sig.key();
 
     // Green
@@ -575,7 +575,7 @@ static QString formatRecipientsDetails(const std::vector<Key> &knownRecipients,
     }
 
     if (knownRecipients.empty()) {
-        return QLatin1String("<i>") + i18np("One unknown recipient.", "%1 unknown recipients.", numRecipients) + QLatin1String("</i>");
+        return QLatin1StringView("<i>") + i18np("One unknown recipient.", "%1 unknown recipients.", numRecipients) + QLatin1String("</i>");
     }
 
     QString details = i18np("Recipient:", "Recipients:", numRecipients);
@@ -583,15 +583,15 @@ static QString formatRecipientsDetails(const std::vector<Key> &knownRecipients,
     if (numRecipients == 1) {
         details += QLatin1Char(' ') + renderKey(knownRecipients.front());
     } else {
-        details += QLatin1String("<ul>");
+        details += QLatin1StringView("<ul>");
         for (const Key &key : knownRecipients) {
-            details += QLatin1String("<li>") + renderKey(key) + QLatin1String("</li>");
+            details += QLatin1StringView("<li>") + renderKey(key) + QLatin1String("</li>");
         }
         if (knownRecipients.size() < numRecipients) {
-            details += QLatin1String("<li><i>") + i18np("One unknown recipient", "%1 unknown recipients", numRecipients - knownRecipients.size())
-                + QLatin1String("</i></li>");
+            details += QLatin1StringView("<li><i>") + i18np("One unknown recipient", "%1 unknown recipients", numRecipients - knownRecipients.size())
+                + QLatin1StringView("</i></li>");
         }
-        details += QLatin1String("</ul>");
+        details += QLatin1StringView("</ul>");
     }
 
     return details;
@@ -636,7 +636,7 @@ static QString formatDecryptionResultDetails(const DecryptionResult &res,
     }
 
     if (!isSigned) {
-        details += i18n("<b>Note:</b> You cannot be sure who encrypted this message as it is not signed.") + QLatin1String("<br/>");
+        details += i18n("<b>Note:</b> You cannot be sure who encrypted this message as it is not signed.") + QLatin1StringView("<br/>");
     }
 
     if (res.isLegacyCipherNoMDC()) {
@@ -1076,6 +1076,7 @@ public:
     bool m_ignoreMDCError = false;
     bool m_extractArchive = false;
     QString m_inputFilePath;
+    QString m_outputFilePath;
     QString m_outputDirectory;
 };
 
@@ -1165,7 +1166,7 @@ void DecryptVerifyTask::autodetectProtocolFromInput()
 
 QString DecryptVerifyTask::label() const
 {
-    return i18n("Decrypting: %1...", d->m_input->label());
+    return i18n("Decrypting %1...", inputLabel());
 }
 
 unsigned long long DecryptVerifyTask::inputSize() const
@@ -1175,12 +1176,18 @@ unsigned long long DecryptVerifyTask::inputSize() const
 
 QString DecryptVerifyTask::inputLabel() const
 {
-    return d->m_input ? d->m_input->label() : QString();
+    return d->m_input ? d->m_input->label() : QFileInfo{d->m_inputFilePath}.fileName();
 }
 
 QString DecryptVerifyTask::outputLabel() const
 {
-    return d->m_output ? d->m_output->label() : d->m_outputDirectory;
+    if (d->m_output) {
+        return d->m_output->label();
+    } else if (!d->m_outputFilePath.isEmpty()) {
+        return QFileInfo{d->m_outputFilePath}.fileName();
+    } else {
+        return d->m_outputDirectory;
+    }
 }
 
 Protocol DecryptVerifyTask::protocol() const
@@ -1213,6 +1220,11 @@ void DecryptVerifyTask::setInputFile(const QString &path)
     d->m_inputFilePath = path;
 }
 
+void DecryptVerifyTask::setOutputFile(const QString &path)
+{
+    d->m_outputFilePath = path;
+}
+
 void DecryptVerifyTask::setOutputDirectory(const QString &directory)
 {
     d->m_outputDirectory = directory;
@@ -1251,6 +1263,20 @@ static void setIgnoreMDCErrorFlag(QGpgME::Job *job, bool ignoreMDCError)
 
 void DecryptVerifyTask::Private::startDecryptVerifyJob()
 {
+#if QGPGME_FILE_JOBS_SUPPORT_DIRECT_FILE_IO
+    if (!m_outputFilePath.isEmpty() && QFile::exists(m_outputFilePath)) {
+        // The output files are always written to a temporary location. Therefore, this can only occur
+        // if two signed/encrypted files with the same name in different folders are verified/decrypted
+        // because they would be written to the same temporary location.
+        QMetaObject::invokeMethod(
+            q,
+            [this]() {
+                slotResult(DecryptionResult{Error::fromCode(GPG_ERR_EEXIST)}, VerificationResult{});
+            },
+            Qt::QueuedConnection);
+        return;
+    }
+#endif
     try {
         std::unique_ptr<QGpgME::DecryptVerifyJob> job{m_backend->decryptVerifyJob()};
         kleo_assert(job);
@@ -1262,8 +1288,19 @@ void DecryptVerifyTask::Private::startDecryptVerifyJob()
                              slotResult(decryptResult, verifyResult, plainText);
                          });
         connect(job.get(), &QGpgME::Job::jobProgress, q, &DecryptVerifyTask::setProgress);
+#if QGPGME_FILE_JOBS_SUPPORT_DIRECT_FILE_IO
+        if (!m_inputFilePath.isEmpty() && !m_outputFilePath.isEmpty()) {
+            job->setInputFile(m_inputFilePath);
+            job->setOutputFile(m_outputFilePath);
+            const auto err = job->startIt();
+        } else {
+            ensureIOOpen(m_input->ioDevice().get(), m_output->ioDevice().get());
+            job->start(m_input->ioDevice(), m_output->ioDevice());
+        }
+#else
         ensureIOOpen(m_input->ioDevice().get(), m_output->ioDevice().get());
         job->start(m_input->ioDevice(), m_output->ioDevice());
+#endif
         q->setJob(job.release());
     } catch (const GpgME::Exception &e) {
         q->emitResult(q->fromDecryptVerifyResult(e.error(), QString::fromLocal8Bit(e.what()), AuditLogEntry()));
@@ -1287,7 +1324,6 @@ void DecryptVerifyTask::Private::startDecryptVerifyArchiveJob()
                 slotResult(decryptResult, verifyResult);
             });
     connect(job.get(), &QGpgME::Job::jobProgress, q, &DecryptVerifyTask::setProgress);
-#if QGPGME_ARCHIVE_JOBS_SUPPORT_INPUT_FILENAME
     // make sure that we don't use an existing output directory
     const auto outputDirectory = ensureUniqueDirectory(m_outputDirectory);
     if (outputDirectory.isEmpty()) {
@@ -1298,11 +1334,6 @@ void DecryptVerifyTask::Private::startDecryptVerifyArchiveJob()
     job->setInputFile(m_inputFilePath);
     job->setOutputDirectory(m_outputDirectory);
     const auto err = job->startIt();
-#else
-    ensureIOOpen(m_input->ioDevice().get(), nullptr);
-    job->setOutputDirectory(m_outputDirectory);
-    const auto err = job->start(m_input->ioDevice());
-#endif
     q->setJob(job.release());
     if (err) {
         q->emitResult(q->fromDecryptVerifyResult(err, {}, {}));
@@ -1479,6 +1510,7 @@ public:
     Protocol m_protocol = UnknownProtocol;
     bool m_extractArchive = false;
     QString m_inputFilePath;
+    QString m_outputFilePath;
     QString m_outputDirectory;
 };
 
@@ -1568,7 +1600,7 @@ void VerifyOpaqueTask::autodetectProtocolFromInput()
 
 QString VerifyOpaqueTask::label() const
 {
-    return i18n("Verifying: %1...", d->m_input->label());
+    return i18n("Verifying %1...", inputLabel());
 }
 
 unsigned long long VerifyOpaqueTask::inputSize() const
@@ -1578,12 +1610,18 @@ unsigned long long VerifyOpaqueTask::inputSize() const
 
 QString VerifyOpaqueTask::inputLabel() const
 {
-    return d->m_input ? d->m_input->label() : QString();
+    return d->m_input ? d->m_input->label() : QFileInfo{d->m_inputFilePath}.fileName();
 }
 
 QString VerifyOpaqueTask::outputLabel() const
 {
-    return d->m_output ? d->m_output->label() : d->m_outputDirectory;
+    if (d->m_output) {
+        return d->m_output->label();
+    } else if (!d->m_outputFilePath.isEmpty()) {
+        return QFileInfo{d->m_outputFilePath}.fileName();
+    } else {
+        return d->m_outputDirectory;
+    }
 }
 
 Protocol VerifyOpaqueTask::protocol() const
@@ -1601,6 +1639,11 @@ void VerifyOpaqueTask::setInputFile(const QString &path)
     d->m_inputFilePath = path;
 }
 
+void VerifyOpaqueTask::setOutputFile(const QString &path)
+{
+    d->m_outputFilePath = path;
+}
+
 void VerifyOpaqueTask::setOutputDirectory(const QString &directory)
 {
     d->m_outputDirectory = directory;
@@ -1618,6 +1661,20 @@ void VerifyOpaqueTask::doStart()
 
 void VerifyOpaqueTask::Private::startVerifyOpaqueJob()
 {
+#if QGPGME_FILE_JOBS_SUPPORT_DIRECT_FILE_IO
+    if (!m_outputFilePath.isEmpty() && QFile::exists(m_outputFilePath)) {
+        // The output files are always written to a temporary location. Therefore, this can only occur
+        // if two signed/encrypted files with the same name in different folders are verified/decrypted
+        // because they would be written to the same temporary location.
+        QMetaObject::invokeMethod(
+            q,
+            [this]() {
+                slotResult(VerificationResult{Error::fromCode(GPG_ERR_EEXIST)});
+            },
+            Qt::QueuedConnection);
+        return;
+    }
+#endif
     try {
         std::unique_ptr<QGpgME::VerifyOpaqueJob> job{m_backend->verifyOpaqueJob()};
         kleo_assert(job);
@@ -1625,8 +1682,19 @@ void VerifyOpaqueTask::Private::startVerifyOpaqueJob()
             slotResult(result, plainText);
         });
         connect(job.get(), &QGpgME::Job::jobProgress, q, &VerifyOpaqueTask::setProgress);
+#if QGPGME_FILE_JOBS_SUPPORT_DIRECT_FILE_IO
+        if (!m_inputFilePath.isEmpty() && !m_outputFilePath.isEmpty()) {
+            job->setInputFile(m_inputFilePath);
+            job->setOutputFile(m_outputFilePath);
+            const auto err = job->startIt();
+        } else {
+            ensureIOOpen(m_input->ioDevice().get(), m_output ? m_output->ioDevice().get() : nullptr);
+            job->start(m_input->ioDevice(), m_output ? m_output->ioDevice() : std::shared_ptr<QIODevice>());
+        }
+#else
         ensureIOOpen(m_input->ioDevice().get(), m_output ? m_output->ioDevice().get() : nullptr);
         job->start(m_input->ioDevice(), m_output ? m_output->ioDevice() : std::shared_ptr<QIODevice>());
+#endif
         q->setJob(job.release());
     } catch (const GpgME::Exception &e) {
         q->emitResult(q->fromVerifyOpaqueResult(e.error(), QString::fromLocal8Bit(e.what()), AuditLogEntry()));
@@ -1646,7 +1714,6 @@ void VerifyOpaqueTask::Private::startDecryptVerifyArchiveJob()
         slotResult(verifyResult);
     });
     connect(job.get(), &QGpgME::DecryptVerifyArchiveJob::dataProgress, q, &VerifyOpaqueTask::setProgress);
-#if QGPGME_ARCHIVE_JOBS_SUPPORT_INPUT_FILENAME
     // make sure that we don't use an existing output directory
     const auto outputDirectory = ensureUniqueDirectory(m_outputDirectory);
     if (outputDirectory.isEmpty()) {
@@ -1657,11 +1724,6 @@ void VerifyOpaqueTask::Private::startDecryptVerifyArchiveJob()
     job->setInputFile(m_inputFilePath);
     job->setOutputDirectory(m_outputDirectory);
     const auto err = job->startIt();
-#else
-    ensureIOOpen(m_input->ioDevice().get(), nullptr);
-    job->setOutputDirectory(m_outputDirectory);
-    const auto err = job->start(m_input->ioDevice());
-#endif
     q->setJob(job.release());
     if (err) {
         q->emitResult(q->fromVerifyOpaqueResult(err, {}, {}));
@@ -1686,9 +1748,14 @@ public:
         q->connect(job, &QGpgME::Job::jobProgress, q, &VerifyDetachedTask::setProgress);
     }
 
+    QString signatureLabel() const;
+    QString signedDataLabel() const;
+
     std::shared_ptr<Input> m_input, m_signedData;
     const QGpgME::Protocol *m_backend = nullptr;
     Protocol m_protocol = UnknownProtocol;
+    QString m_signatureFilePath;
+    QString m_signedFilePath;
 };
 
 void VerifyDetachedTask::Private::slotResult(const VerificationResult &result)
@@ -1712,6 +1779,16 @@ void VerifyDetachedTask::Private::slotResult(const VerificationResult &result)
     }
 }
 
+QString VerifyDetachedTask::Private::signatureLabel() const
+{
+    return m_input ? m_input->label() : m_signatureFilePath;
+}
+
+QString VerifyDetachedTask::Private::signedDataLabel() const
+{
+    return m_signedData ? m_signedData->label() : m_signedFilePath;
+}
+
 VerifyDetachedTask::VerifyDetachedTask(QObject *parent)
     : AbstractDecryptVerifyTask(parent)
     , d(new Private(this))
@@ -1734,6 +1811,16 @@ void VerifyDetachedTask::setSignedData(const std::shared_ptr<Input> &signedData)
     kleo_assert(d->m_signedData && d->m_signedData->ioDevice());
 }
 
+void VerifyDetachedTask::setSignatureFile(const QString &path)
+{
+    d->m_signatureFilePath = path;
+}
+
+void VerifyDetachedTask::setSignedFile(const QString &path)
+{
+    d->m_signedFilePath = path;
+}
+
 void VerifyDetachedTask::setProtocol(Protocol prot)
 {
     kleo_assert(prot != UnknownProtocol);
@@ -1763,28 +1850,31 @@ unsigned long long VerifyDetachedTask::inputSize() const
 
 QString VerifyDetachedTask::label() const
 {
-    if (d->m_signedData) {
+    const QString signedDataLabel = d->signedDataLabel();
+    if (!signedDataLabel.isEmpty()) {
         return xi18nc(
             "Verification of a detached signature in progress. The first file contains the data."
             "The second file is the signature file.",
-            "Verifying: <filename>%1</filename> with <filename>%2</filename>...",
-            d->m_signedData->label(),
-            d->m_input->label());
+            "Verifying <filename>%1</filename> with <filename>%2</filename>...",
+            signedDataLabel,
+            d->signatureLabel());
     }
-    return i18n("Verifying signature: %1...", d->m_input->label());
+    return i18n("Verifying signature %1...", d->signatureLabel());
 }
 
 QString VerifyDetachedTask::inputLabel() const
 {
-    if (d->m_signedData && d->m_input) {
+    const QString signatureLabel = d->signatureLabel();
+    const QString signedDataLabel = d->signedDataLabel();
+    if (!signedDataLabel.isEmpty() && !signatureLabel.isEmpty()) {
         return xi18nc(
             "Verification of a detached signature summary. The first file contains the data."
             "The second file is signature.",
             "Verified <filename>%1</filename> with <filename>%2</filename>",
-            d->m_signedData->label(),
-            d->m_input->label());
+            signedDataLabel,
+            signatureLabel);
     }
-    return d->m_input ? d->m_input->label() : QString();
+    return signatureLabel;
 }
 
 QString VerifyDetachedTask::outputLabel() const
@@ -1804,9 +1894,21 @@ void VerifyDetachedTask::doStart()
         std::unique_ptr<QGpgME::VerifyDetachedJob> job{d->m_backend->verifyDetachedJob()};
         kleo_assert(job);
         d->registerJob(job.get());
+#if QGPGME_FILE_JOBS_SUPPORT_DIRECT_FILE_IO
+        if (d->m_protocol == GpgME::OpenPGP && !d->m_signatureFilePath.isEmpty() && !d->m_signedFilePath.isEmpty()) {
+            job->setSignatureFile(d->m_signatureFilePath);
+            job->setSignedFile(d->m_signedFilePath);
+            job->startIt();
+        } else {
+            ensureIOOpen(d->m_input->ioDevice().get(), nullptr);
+            ensureIOOpen(d->m_signedData->ioDevice().get(), nullptr);
+            job->start(d->m_input->ioDevice(), d->m_signedData->ioDevice());
+        }
+#else
         ensureIOOpen(d->m_input->ioDevice().get(), nullptr);
         ensureIOOpen(d->m_signedData->ioDevice().get(), nullptr);
         job->start(d->m_input->ioDevice(), d->m_signedData->ioDevice());
+#endif
         setJob(job.release());
     } catch (const GpgME::Exception &e) {
         emitResult(fromVerifyDetachedResult(e.error(), QString::fromLocal8Bit(e.what()), AuditLogEntry()));
