@@ -10,6 +10,8 @@
 */
 #pragma once
 
+#include <Libkleo/KeyUsage>
+
 #include <QWidget>
 
 #include <memory>
@@ -17,6 +19,7 @@
 namespace GpgME
 {
 class Key;
+class UserID;
 }
 
 namespace Kleo
@@ -32,7 +35,7 @@ class KeyGroup;
  * The widget will use a single line HBox Layout. For larger dialog
  * see certificateslectiondialog.
  */
-class CertificateLineEdit: public QWidget
+class CertificateLineEdit : public QWidget
 {
     Q_OBJECT
 public:
@@ -41,13 +44,20 @@ public:
      * If parent is not NULL the model is not taken
      * over but the parent argument used as the parent of the model.
      *
-     * @param model: The keylistmodel to use.
-     * @param parent: The usual widget parent.
-     * @param filter: The filters to use. See certificateselectiondialog.
+     * @param model  The keylistmodel to use.
+     * @param usage  the desired usage of the certificate
+     * @param filter The filters to use. See certificateselectiondialog.
+     * @param parent The usual widget parent.
+     *
+     * \a usage is used to mark certificates that cannot be used for the desired
+     * usage with an appropriate icon. This is useful in combination with a suitable
+     * key filter.
+     * For example, the key filter could filter out any certificates without
+     * encryption subkeys and the usage flags would mark certificates with expired
+     * encryption subkeys as unusable, so that the users see that there is a
+     * certificate, but that it cannot be used.
      */
-    explicit CertificateLineEdit(AbstractKeyListModel *model,
-                                 KeyFilter *filter = nullptr,
-                                 QWidget *parent = nullptr);
+    explicit CertificateLineEdit(AbstractKeyListModel *model, KeyUsage::Flags usage = KeyUsage::None, KeyFilter *filter = nullptr, QWidget *parent = nullptr);
 
     ~CertificateLineEdit() override;
 
@@ -56,6 +66,8 @@ public:
 
     KeyGroup group() const;
 
+    GpgME::UserID userID() const;
+
     /** The current text */
     QString text() const;
 
@@ -74,6 +86,9 @@ public:
     /** Set the preselected group for this widget. */
     void setGroup(const KeyGroup &group);
 
+    /** Set the preselected userId for this widget. */
+    void setUserID(const GpgME::UserID &userID);
+
     /** Set the used keyfilter. */
     void setKeyFilter(const std::shared_ptr<KeyFilter> &filter);
 
