@@ -14,29 +14,31 @@
 
 #include <utils/kleo_assert.h>
 
+#include <Libkleo/Algorithm>
+
 #include <KGuiItem>
 #include <KLocalizedString>
-#include <QPushButton>
 #include <KStandardGuiItem>
+#include <QPushButton>
 
+#include "kleopatra_debug.h"
 #include <QDialogButtonBox>
 #include <QFrame>
 #include <QLabel>
 #include <QStackedWidget>
 #include <QTimer>
 #include <QVBoxLayout>
-#include "kleopatra_debug.h"
 
 #include <map>
 #include <set>
 
-
 using namespace Kleo::Crypto::Gui;
 
 class Wizard::Private
 {
     friend class ::Wizard;
     Wizard *const q;
+
 public:
     explicit Private(Wizard *qq);
     ~Private();
@@ -66,20 +68,21 @@ private:
 };
 
 Wizard::Private::Private(Wizard *qq)
-    : q(qq), stack(new QStackedWidget)
+    : q(qq)
+    , stack(new QStackedWidget)
 {
     nextPageTimer = new QTimer(q);
     nextPageTimer->setInterval(0);
     connect(nextPageTimer, &QTimer::timeout, q, &Wizard::next);
-    nextItem = KGuiItem(i18n("&Next"));
+    nextItem = KGuiItem(i18nc("@action:button", "&Next"));
     finishItem = KStandardGuiItem::ok();
-    QVBoxLayout *const top = new QVBoxLayout(q);
+    auto const top = new QVBoxLayout(q);
     top->setContentsMargins(0, 0, 0, 0);
     titleFrame = new QFrame;
     titleFrame->setFrameShape(QFrame::StyledPanel);
     titleFrame->setAutoFillBackground(true);
     titleFrame->setBackgroundRole(QPalette::Base);
-    QVBoxLayout *const titleLayout = new QVBoxLayout(titleFrame);
+    auto const titleLayout = new QVBoxLayout(titleFrame);
     titleLabel = new QLabel;
     titleLayout->addWidget(titleLabel);
     subTitleLabel = new QLabel;
@@ -94,16 +97,16 @@ Wizard::Private::Private(Wizard *qq)
     explanationFrame->setFrameShape(QFrame::StyledPanel);
     explanationFrame->setAutoFillBackground(true);
     explanationFrame->setBackgroundRole(QPalette::Base);
-    QVBoxLayout *const explanationLayout = new QVBoxLayout(explanationFrame);
+    auto const explanationLayout = new QVBoxLayout(explanationFrame);
     explanationLabel = new QLabel;
     explanationLabel->setWordWrap(true);
     explanationLayout->addWidget(explanationLabel);
     top->addWidget(explanationFrame);
     explanationFrame->setVisible(false);
 
-    QWidget *buttonWidget = new QWidget;
-    QHBoxLayout *buttonLayout = new QHBoxLayout(buttonWidget);
-    QDialogButtonBox *const box = new QDialogButtonBox;
+    auto buttonWidget = new QWidget;
+    auto buttonLayout = new QHBoxLayout(buttonWidget);
+    auto const box = new QDialogButtonBox;
 
     cancelButton = box->addButton(QDialogButtonBox::Cancel);
     q->connect(cancelButton, &QPushButton::clicked, q, &Wizard::reject);
@@ -126,7 +129,7 @@ Wizard::Private::Private(Wizard *qq)
 
 Wizard::Private::~Private()
 {
-    qCDebug(KLEOPATRA_LOG);
+    qCDebug(KLEOPATRA_LOG) << q << __func__;
 }
 
 bool Wizard::Private::isLastPage(int id) const
@@ -175,14 +178,14 @@ void Wizard::Private::updateHeader()
 }
 
 Wizard::Wizard(QWidget *parent, Qt::WindowFlags f)
-    : QDialog(parent, f), d(new Private(this))
+    : QDialog(parent, f)
+    , d(new Private(this))
 {
-
 }
 
 Wizard::~Wizard()
 {
-    qCDebug(KLEOPATRA_LOG);
+    qCDebug(KLEOPATRA_LOG) << this << __func__;
 }
 
 void Wizard::setPage(int id, WizardPage *widget)
@@ -260,7 +263,7 @@ void Wizard::next()
         current->onNext();
     }
     onNext(d->currentId);
-    std::vector<int>::const_iterator it = qBinaryFind(d->pageOrder.begin(), d->pageOrder.end(), d->currentId);
+    auto it = Kleo::binary_find(d->pageOrder.begin(), d->pageOrder.end(), d->currentId);
     Q_ASSERT(it != d->pageOrder.end());
 
     do {
@@ -281,7 +284,7 @@ int Wizard::Private::previousPage() const
         return InvalidPage;
     }
 
-    std::vector<int>::const_iterator it = qBinaryFind(pageOrder.begin(), pageOrder.end(), currentId);
+    auto it = Kleo::binary_find(pageOrder.begin(), pageOrder.end(), currentId);
     if (it == pageOrder.begin() || it == pageOrder.end()) {
         return InvalidPage;
     }
@@ -308,7 +311,7 @@ const WizardPage *Wizard::page(int id) const
         return nullptr;
     }
 
-    const std::map<int, WizardPage *>::const_iterator it = d->idToPage.find(id);
+    const auto it = d->idToPage.find(id);
     kleo_assert(it != d->idToPage.end());
     return (*it).second;
 }
@@ -339,7 +342,7 @@ WizardPage *Wizard::page(int id)
         return nullptr;
     }
 
-    const std::map<int, WizardPage *>::const_iterator it = d->idToPage.find(id);
+    const auto it = d->idToPage.find(id);
     kleo_assert(it != d->idToPage.end());
     return (*it).second;
 }
