@@ -19,6 +19,7 @@
 #include "certificatedumpwidget.h"
 #include "dialogs/weboftrustwidget.h"
 #include "kleopatra_debug.h"
+#include "revokerswidget.h"
 #include "subkeyswidget.h"
 #include "trustchainwidget.h"
 #include "useridswidget.h"
@@ -46,6 +47,8 @@
 #include <gpgme++/key.h>
 #include <gpgme++/keylistresult.h>
 
+#include <gpgme.h>
+
 #include <QGpgME/Debug>
 #include <QGpgME/KeyListJob>
 #include <QGpgME/Protocol>
@@ -60,6 +63,7 @@
 #include <QLocale>
 #include <QMenu>
 #include <QPushButton>
+#include <QStackedWidget>
 #include <QStringBuilder>
 #include <QTreeWidget>
 #include <QVBoxLayout>
@@ -138,6 +142,7 @@ private:
         std::unique_ptr<InfoField> primaryUserIdField;
         std::unique_ptr<InfoField> privateKeyInfoField;
         std::unique_ptr<InfoField> statusField;
+        std::unique_ptr<InfoField> usageField;
 
         QListWidget *smimeAddressList = nullptr;
 
@@ -147,6 +152,7 @@ private:
         TrustChainWidget *trustChainWidget = nullptr;
         CertificateDumpWidget *certificateDumpWidget = nullptr;
         CardInfoTab *cardInfoTab = nullptr;
+        RevokersWidget *revokersWidget = nullptr;
 
         void setupUi(QWidget *parent)
         {
@@ -230,10 +236,15 @@ private:
                 gridLayout->addWidget(complianceField->label(), row, 0);
                 gridLayout->addLayout(complianceField->layout(), row, 1);
 
+                row++;
+                usageField = std::make_unique<InfoField>(i18n("Usage:"), parent);
+                gridLayout->addWidget(usageField->label(), row, 0);
+                gridLayout->addLayout(usageField->layout(), row, 1);
+
                 row++;
                 trustedIntroducerField = std::make_unique<InfoField>(i18n("Trusted introducer for:"), parent);
                 gridLayout->addWidget(trustedIntroducerField->label(), row, 0);
-                trustedIntroducerField->setToolTip(i18n("See certifications for details."));
+                trustedIntroducerField->setToolTip(i18nc("@info:tooltip", "See certifications for details."));
                 gridLayout->addLayout(trustedIntroducerField->layout(), row, 1);
 
                 row++;
@@ -245,6 +256,8 @@ private:
             }
 
             tabWidget = new QTabWidget(parent);
+            tabWidget->setDocumentMode(true); // we don't want a frame around the page widgets
+            tabWidget->tabBar()->setDrawBase(false); // only draw the tabs
 
             mainLayout->addWidget(tabWidget);
 
@@ -252,6 +265,8 @@ private:
 
             tabWidget->addTab(userIDs, i18nc("@title:tab", "User IDs"));
             smimeAddressList = new QListWidget{parent};
+            // Breeze draws no frame for scroll areas that are the only widget in a layout...unless we force it
+            smimeAddressList->setProperty("_breeze_force_frame", true);
             smimeAddressList->setAccessibleName(i18n("Related addresses"));
             smimeAddressList->setEditTriggers(QAbstractItemView::NoEditTriggers);
             smimeAddressList->setSelectionMode(QAbstractItemView::SingleSelection);
@@ -271,6 +286,12 @@ private:
 
             certificateDumpWidget = new CertificateDumpWidget(parent);
             tabWidget->addTab(certificateDumpWidget, i18nc("@title:tab", "Certificate Dump"));
+
+#if GPGME_VERSION_NUMBER >= 0x011800 // 1.24.0
+            revokersWidget = new RevokersWidget(parent);
+            const auto index = tabWidget->addTab(revokersWidget, i18nc("@title:tab", "Revokers"));
+            tabWidget->setTabVisible(index, false);
+#endif
         }
     } ui;
 };
@@ -343,6 +364,11 @@ void CertificateDetailsWidget::Private::setupCommonProperties()
         }
     } else if (!subkey.isSecret()) {
         storage = i18nc("key is 'offline key', i.e. secret key is not stored on this computer", "offline");
+    } else if (KeyCache::instance()->cardsForSubkey(subkey).size() > 0) {
+        storage = i18ncp("As in 'this key is stored on this computer and on smart card(s)'",
+                         "On this computer and on a smart card",
+                         "On this computer and on %1 smart cards",
+                         KeyCache::instance()->cardsForSubkey(subkey).size());
     } else {
         storage = i18nc("As in 'this secret key is stored on this computer'", "on this computer");
     }
@@ -350,6 +376,28 @@ void CertificateDetailsWidget::Private::setupCommonProperties()
     if (DeVSCompliance::isCompliant()) {
         ui.complianceField->setValue(Kleo::Formatting::complianceStringForKey(key));
     }
+
+    ui.usageField->setVisible(key.protocol() == GpgME::CMS);
+
+    QStringList usage;
+
+    if (subkey.canEncrypt()) {
+        usage += i18n("encryption");
+    }
+    if (subkey.canSign()) {
+        usage += i18n("signing");
+    }
+    if (subkey.canCertify()) {
+        usage += i18n("certification");
+    }
+    if (subkey.canAuthenticate()) {
+        usage += i18n("authentication");
+    }
+    if (subkey.isQualified()) {
+        usage += i18nc("as in: can be used for ...", "qualified signatures");
+    }
+
+    ui.usageField->setValue(usage.join(i18nc("Separator between words in a list", ", ")));
     ui.cardInfoTab->setKey(key);
 }
 
@@ -508,6 +556,10 @@ void CertificateDetailsWidget::Private::setupPGPProperties()
     ui.userIDs->setKey(key);
     ui.subKeysWidget->setKey(key);
     ui.webOfTrustWidget->setKey(key);
+#if GPGME_VERSION_NUMBER >= 0x011800 // 1.24.0
+    ui.revokersWidget->setKey(key);
+    setTabVisible(ui.revokersWidget, key.numRevocationKeys() > 0);
+#endif
 
     const auto trustDomains = accumulateTrustDomains(key.userIDs());
     ui.trustedIntroducerField->setVisible(!trustDomains.empty());
@@ -652,6 +704,7 @@ void CertificateDetailsWidget::setKey(const GpgME::Key &key)
     auto ctx = QGpgME::Job::context(job);
     ctx->addKeyListMode(GpgME::WithTofu);
     ctx->addKeyListMode(GpgME::SignatureNotations);
+    ctx->addKeyListMode(GpgME::WithKeygrip);
     if (key.hasSecret()) {
         ctx->addKeyListMode(GpgME::WithSecret);
     }
