@@ -19,11 +19,9 @@
 #include <KLocalizedString>
 
 #include <QIcon>
-#include <QTextDocument> // for Qt::escape
 
 #include <gpgme++/error.h>
 
-
 using namespace Kleo;
 using namespace Kleo::Dialogs;
 using namespace GpgME;
@@ -35,17 +33,17 @@ enum State {
     Ongoing,
     Ok,
     Failed,
-    NumStates
+    NumStates,
 };
 
 const char *icons[] = {
     // PENDING(marc) use better icons, once available
-    "",                          // Unknown
-    "",                          // NotSet
-    "security-medium",           // AlreadySet
+    "", // Unknown
+    "", // NotSet
+    "security-medium", // AlreadySet
     "movie-process-working-kde", // Ongoing
-    "security-high",             // Ok
-    "security-low",              // Failed
+    "security-high", // Ok
+    "security-low", // Failed
 };
 
 static_assert(sizeof icons / sizeof(*icons) == NumStates, "");
@@ -53,19 +51,21 @@ static_assert(sizeof("movie-") == 7, "");
 
 static void update_widget(State state, bool delay, QLabel *resultLB, QLabel *lb, QPushButton *pb, QLabel *statusLB)
 {
-    Q_ASSERT(state >= 0); Q_ASSERT(state < NumStates);
+    Q_ASSERT(state >= 0);
+    Q_ASSERT(state < NumStates);
     const char *icon = icons[state];
     if (qstrncmp(icon, "movie-", sizeof("movie-") - 1) == 0) {
-        resultLB->setMovie(KIconLoader::global()->loadMovie(QLatin1String(icon + sizeof("movie-")), KIconLoader::NoGroup));
+        resultLB->setMovie(KIconLoader::global()->loadMovie(QLatin1StringView(icon + sizeof("movie-")), KIconLoader::NoGroup));
     } else if (icon && *icon) {
-        resultLB->setPixmap(QIcon::fromTheme(QLatin1String(icon)).pixmap(32));
+        resultLB->setPixmap(QIcon::fromTheme(QLatin1StringView(icon)).pixmap(32));
     } else {
         resultLB->setPixmap(QPixmap());
     }
     lb->setEnabled((state == NotSet || state == Failed) && !delay);
     pb->setEnabled((state == NotSet || state == Failed) && !delay);
     if (state == AlreadySet) {
-        statusLB->setText(xi18nc("@info", "No NullPin found. <warning>If this PIN was not set by you personally, the card might have been tampered with.</warning>"));
+        statusLB->setText(
+            xi18nc("@info", "No NullPin found. <warning>If this PIN was not set by you personally, the card might have been tampered with.</warning>"));
     }
 }
 
@@ -75,9 +75,7 @@ static QString format_error(const Error &err)
         return i18nc("@info", "Canceled setting PIN.");
     }
     if (err)
-        return xi18nc("@info",
-                      "There was an error setting the PIN: <message>%1</message>.",
-                      Formatting::errorAsString(err).toHtmlEscaped());
+        return xi18nc("@info", "There was an error setting the PIN: <message>%1</message>.", Formatting::errorAsString(err).toHtmlEscaped());
     else {
         return i18nc("@info", "PIN set successfully.");
     }
@@ -87,14 +85,14 @@ class SetInitialPinDialog::Private
 {
     friend class ::Kleo::Dialogs::SetInitialPinDialog;
     SetInitialPinDialog *const q;
+
 public:
     explicit Private(SetInitialPinDialog *qq)
-        : q(qq),
-          nksState(Unknown),
-          sigGState(Unknown),
-          ui(q)
+        : q(qq)
+        , nksState(Unknown)
+        , sigGState(Unknown)
+        , ui(q)
     {
-
     }
 
 private:
@@ -117,10 +115,8 @@ private:
 private:
     void updateWidgets()
     {
-        update_widget(nksState,  false,
-                      ui.nksResultIcon,  ui.nksLB,  ui.nksPB,  ui.nksStatusLB);
-        update_widget(sigGState, nksState == NotSet || nksState == Failed || nksState == Ongoing,
-                      ui.sigGResultIcon, ui.sigGLB, ui.sigGPB, ui.sigGStatusLB);
+        update_widget(nksState, false, ui.nksResultIcon, ui.nksLB, ui.nksPB, ui.nksStatusLB);
+        update_widget(sigGState, nksState == NotSet || nksState == Failed || nksState == Ongoing, ui.sigGResultIcon, ui.sigGLB, ui.sigGPB, ui.sigGStatusLB);
         ui.closePB()->setEnabled(q->isComplete());
         ui.cancelPB()->setEnabled(!q->isComplete());
     }
@@ -155,12 +151,14 @@ private:
 };
 
 SetInitialPinDialog::SetInitialPinDialog(QWidget *p)
-    : QDialog(p), d(new Private(this))
+    : QDialog(p)
+    , d(new Private(this))
 {
-
 }
 
-SetInitialPinDialog::~SetInitialPinDialog() {}
+SetInitialPinDialog::~SetInitialPinDialog()
+{
+}
 
 void SetInitialPinDialog::setNksPinPresent(bool on)
 {
@@ -177,26 +175,24 @@ void SetInitialPinDialog::setSigGPinPresent(bool on)
 void SetInitialPinDialog::setNksPinSettingResult(const Error &err)
 {
     d->ui.nksStatusLB->setText(format_error(err));
-    d->nksState =
-        err.isCanceled() ? NotSet :
-        err              ? Failed :
-        Ok;
+    d->nksState = (err.isCanceled() ? NotSet //
+                       : err        ? Failed
+                                    : Ok);
     d->updateWidgets();
 }
 
 void SetInitialPinDialog::setSigGPinSettingResult(const Error &err)
 {
     d->ui.sigGStatusLB->setText(format_error(err));
-    d->sigGState =
-        err.isCanceled() ? NotSet :
-        err              ? Failed :
-        Ok;
+    d->sigGState = (err.isCanceled() ? NotSet //
+                        : err        ? Failed
+                                     : Ok);
     d->updateWidgets();
 }
 
 bool SetInitialPinDialog::isComplete() const
 {
-    return (d->nksState  == Ok || d->nksState  == AlreadySet);
+    return (d->nksState == Ok || d->nksState == AlreadySet);
 }
 
 #include "moc_setinitialpindialog.cpp"
