@@ -21,11 +21,14 @@
 #include "systrayicon.h"
 
 #include <conf/configuredialog.h>
+#include <conf/groupsconfigdialog.h>
+#include <dialogs/smartcardwindow.h>
 #include <smartcard/readerstatus.h>
 
 #include <Libkleo/GnuPG>
 #include <utils/kdpipeiodevice.h>
 #include <utils/log.h>
+#include <utils/userinfo.h>
 
 #include <gpgme++/key.h>
 
@@ -51,6 +54,10 @@
 
 #include "dialogs/updatenotification.h"
 
+#ifdef Q_OS_WIN
+#include <utils/winapi-helpers.h>
+#endif
+
 #include "kleopatra_debug.h"
 #include <KColorSchemeManager>
 #include <KIconLoader>
@@ -74,7 +81,7 @@
 #include <memory>
 
 #ifdef Q_OS_WIN
-#include <QtPlatformHeaders/QWindowsWindowFunctions>
+#include <windows.h>
 #endif
 
 using namespace Kleo;
@@ -160,8 +167,9 @@ public:
         : q(qq)
         , ignoreNewInstance(true)
         , firstNewInstance(true)
+#ifndef QT_NO_SYSTEMTRAYICON
         , sysTray(nullptr)
-        , groupConfig{std::make_shared<KeyGroupConfig>(QStringLiteral("kleopatragroupsrc"))}
+#endif
     {
     }
     ~Private()
@@ -176,10 +184,7 @@ public:
         Q_ASSERT(readerStatus);
         sysTray = new SysTrayIcon();
         sysTray->setFirstCardWithNullPin(readerStatus->firstCardWithNullPin());
-        sysTray->setAnyCardCanLearnKeys(readerStatus->anyCardCanLearnKeys());
-
         connect(readerStatus.get(), &SmartCard::ReaderStatus::firstCardWithNullPinChanged, sysTray, &SysTrayIcon::setFirstCardWithNullPin);
-        connect(readerStatus.get(), &SmartCard::ReaderStatus::anyCardCanLearnKeysChanged, sysTray, &SysTrayIcon::setAnyCardCanLearnKeys);
 #endif
     }
 
@@ -208,7 +213,9 @@ public:
     bool firstNewInstance;
     QPointer<FocusFrame> focusFrame;
     QPointer<ConfigureDialog> configureDialog;
+    QPointer<GroupsConfigDialog> groupsConfigDialog;
     QPointer<MainWindow> mainWindow;
+    QPointer<SmartCardWindow> smartCardWindow;
     std::unique_ptr<SmartCard::ReaderStatus> readerStatus;
 #ifndef QT_NO_SYSTEMTRAYICON
     SysTrayIcon *sysTray;
@@ -288,6 +295,16 @@ public:
             focusFrame->setWidget(nullptr);
         }
     }
+    MainWindow *getOrCreateMainWindow()
+    {
+        auto mw = q->mainWindow();
+        if (!mw) {
+            mw = new MainWindow;
+            mw->setAttribute(Qt::WA_DeleteOnClose);
+            q->setMainWindow(mw);
+        }
+        return mw;
+    }
 };
 
 KleopatraApplication::KleopatraApplication(int &argc, char *argv[])
@@ -298,6 +315,24 @@ KleopatraApplication::KleopatraApplication(int &argc, char *argv[])
     // because this interferes with column by column navigation that is required
     // for accessibility
     setStyleSheet(QStringLiteral("QTreeView { arrow-keys-navigate-into-children: 0; }"));
+#ifdef Q_OS_WIN
+    if (SystemInfo::isHighContrastModeActive()) {
+        // use colors specified by Windows if high-contrast mode is active
+        QPalette highContrastPalette = palette();
+
+        const QColor linkColor = win_getSysColor(COLOR_HOTLIGHT);
+        highContrastPalette.setColor(QPalette::All, QPalette::Link, linkColor);
+        highContrastPalette.setColor(QPalette::All, QPalette::LinkVisited, linkColor);
+
+        const QColor disabledColor = win_getSysColor(COLOR_GRAYTEXT);
+        highContrastPalette.setColor(QPalette::Disabled, QPalette::WindowText, disabledColor);
+        highContrastPalette.setColor(QPalette::Disabled, QPalette::Text, disabledColor);
+        highContrastPalette.setColor(QPalette::Disabled, QPalette::ButtonText, disabledColor);
+        highContrastPalette.setColor(QPalette::All, QPalette::PlaceholderText, disabledColor);
+
+        setPalette(highContrastPalette);
+    }
+#endif
     connect(this, &QApplication::focusChanged, this, [this](QWidget *, QWidget *now) {
         d->updateFocusFrame(now);
     });
@@ -305,9 +340,9 @@ KleopatraApplication::KleopatraApplication(int &argc, char *argv[])
 
 void KleopatraApplication::init()
 {
-#ifdef Q_OS_WIN
-    QWindowsWindowFunctions::setWindowActivationBehavior(QWindowsWindowFunctions::AlwaysActivateWindow);
-#endif
+    const QString groupConfigPath = Kleo::gnupgHomeDirectory() + QStringLiteral("/kleopatra/kleopatragroupsrc");
+    d->groupConfig = std::make_shared<KeyGroupConfig>(groupConfigPath);
+
     const auto blockedUrlSchemes = Settings{}.blockedUrlSchemes();
     for (const auto &scheme : blockedUrlSchemes) {
         QDesktopServices::setUrlHandler(scheme, this, "blockUrl");
@@ -337,9 +372,15 @@ void KleopatraApplication::init()
 #endif
 
 #ifndef QT_NO_SYSTEMTRAYICON
-    d->sysTray->show();
+    if (d->sysTray) {
+        d->sysTray->show();
+    }
 #endif
-    setQuitOnLastWindowClosed(false);
+    if (!Kleo::userIsElevated()) {
+        // For users running Kleo with elevated permissions on Windows we
+        // always quit the application when the last window is closed.
+        setQuitOnLastWindowClosed(false);
+    }
 
     // Sync config when we are about to quit
     connect(this, &QApplication::aboutToQuit, this, []() {
@@ -349,6 +390,8 @@ void KleopatraApplication::init()
 
 KleopatraApplication::~KleopatraApplication()
 {
+    delete d->groupsConfigDialog;
+    delete d->smartCardWindow;
     delete d->mainWindow;
 }
 
@@ -442,7 +485,7 @@ QString KleopatraApplication::newInstance(const QCommandLineParser &parser, cons
     if (queryMode) {
         needle = parser.positionalArguments().join(QLatin1Char(' '));
     }
-    if (needle.startsWith(QLatin1String("openpgp4fpr:"))) {
+    if (needle.startsWith(QLatin1StringView("openpgp4fpr:"))) {
         needle.remove(0, 12);
     }
 
@@ -549,25 +592,7 @@ QString KleopatraApplication::newInstance(const QCommandLineParser &parser, cons
                     errors << i18n("Cannot read \"%1\"", fileName);
                 }
             }
-            const QList<Command *> allCmds = Command::commandsForFiles(files);
-            for (Command *cmd : allCmds) {
-                if (parentId) {
-                    cmd->setParentWId(parentId);
-                } else {
-                    MainWindow *mw = mainWindow();
-                    if (!mw) {
-                        mw = new MainWindow;
-                        mw->setAttribute(Qt::WA_DeleteOnClose);
-                        setMainWindow(mw);
-                        d->connectConfigureDialog();
-                    }
-                    cmd->setParentWidget(mw);
-                }
-                if (dynamic_cast<ImportCertificateFromFileCommand *>(cmd)) {
-                    openOrRaiseMainWindow();
-                }
-                cmd->start();
-            }
+            handleFiles(files, parentId);
         }
     }
     d->firstNewInstance = false;
@@ -584,18 +609,23 @@ QString KleopatraApplication::newInstance(const QCommandLineParser &parser, cons
     return errors.join(QLatin1Char('\n'));
 }
 
-#ifndef QT_NO_SYSTEMTRAYICON
-const SysTrayIcon *KleopatraApplication::sysTrayIcon() const
+void KleopatraApplication::handleFiles(const QStringList &files, WId parentId)
 {
-    return d->sysTray;
+    auto mw = d->getOrCreateMainWindow();
+    const QList<Command *> allCmds = Command::commandsForFiles(files, mw->keyListController());
+    for (Command *cmd : allCmds) {
+        if (parentId) {
+            cmd->setParentWId(parentId);
+        } else {
+            cmd->setParentWidget(mw);
+        }
+        if (dynamic_cast<ImportCertificateFromFileCommand *>(cmd)) {
+            openOrRaiseMainWindow();
+        }
+        cmd->start();
+    }
 }
 
-SysTrayIcon *KleopatraApplication::sysTrayIcon()
-{
-    return d->sysTray;
-}
-#endif
-
 const MainWindow *KleopatraApplication::mainWindow() const
 {
     return d->mainWindow;
@@ -616,7 +646,9 @@ void KleopatraApplication::setMainWindow(MainWindow *mainWindow)
 
     d->mainWindow = mainWindow;
 #ifndef QT_NO_SYSTEMTRAYICON
-    d->sysTray->setMainWindow(mainWindow);
+    if (d->sysTray) {
+        d->sysTray->setMainWindow(mainWindow);
+    }
 #endif
 
     d->connectConfigureDialog();
@@ -650,6 +682,11 @@ void KleopatraApplication::toggleMainWindowVisibility()
     } else {
         openOrRaiseMainWindow();
     }
+    if (mainWindow()->isVisible()) {
+        mainWindow()->exportWindow();
+    } else {
+        mainWindow()->unexportWindow();
+    }
 }
 
 void KleopatraApplication::restoreMainWindow()
@@ -667,31 +704,30 @@ void KleopatraApplication::restoreMainWindow()
         return;
     }
 
-    auto mw = new MainWindow;
+    auto mw = d->getOrCreateMainWindow();
     if (KMainWindow::canBeRestored(1)) {
         // restore to hidden state, Mainwindow::readProperties() will
         // restore saved visibility.
         mw->restore(1, false);
     }
-
-    mw->setAttribute(Qt::WA_DeleteOnClose);
-    setMainWindow(mw);
-    d->connectConfigureDialog();
 }
 
 void KleopatraApplication::openOrRaiseMainWindow()
 {
-    MainWindow *mw = mainWindow();
-    if (!mw) {
-        mw = new MainWindow;
-        mw->setAttribute(Qt::WA_DeleteOnClose);
-        setMainWindow(mw);
-        d->connectConfigureDialog();
-    }
+    auto mw = d->getOrCreateMainWindow();
     open_or_raise(mw);
     UpdateNotification::checkUpdate(mw);
 }
 
+void KleopatraApplication::openOrRaiseSmartCardWindow()
+{
+    if (!d->smartCardWindow) {
+        d->smartCardWindow = new SmartCardWindow;
+        d->smartCardWindow->setAttribute(Qt::WA_DeleteOnClose);
+    }
+    open_or_raise(d->smartCardWindow);
+}
+
 void KleopatraApplication::openConfigDialogWithForeignParent(WId parentWId)
 {
     if (!d->configureDialog) {
@@ -723,6 +759,18 @@ void KleopatraApplication::openOrRaiseConfigDialog()
     openConfigDialogWithForeignParent(0);
 }
 
+void KleopatraApplication::openOrRaiseGroupsConfigDialog(QWidget *parent)
+{
+    if (!d->groupsConfigDialog) {
+        d->groupsConfigDialog = new GroupsConfigDialog{parent};
+        d->groupsConfigDialog->setAttribute(Qt::WA_DeleteOnClose);
+    } else {
+        // reparent the dialog to ensure it's shown on top of the (modal) parent
+        d->groupsConfigDialog->setParent(parent, Qt::Dialog);
+    }
+    open_or_raise(d->groupsConfigDialog);
+}
+
 #ifndef QT_NO_SYSTEMTRAYICON
 void KleopatraApplication::startMonitoringSmartCard()
 {
