@@ -11,9 +11,7 @@
 
 #include <QObject>
 
-#include <kleo-assuan.h> // for assuan_fd_t
-
-#include <utils/pimpl_ptr.h>
+#include <assuan.h> // for assuan_fd_t
 
 #include <memory>
 #include <string>
@@ -28,8 +26,8 @@ class AssuanServerConnection : public QObject
 {
     Q_OBJECT
 public:
-    AssuanServerConnection(assuan_fd_t fd, const std::vector< std::shared_ptr<AssuanCommandFactory> > &factories, QObject *parent = nullptr);
-    ~AssuanServerConnection();
+    AssuanServerConnection(assuan_fd_t fd, const std::vector<std::shared_ptr<AssuanCommandFactory>> &factories, QObject *parent = nullptr);
+    ~AssuanServerConnection() override;
 
 public Q_SLOTS:
     void enableCryptoCommands(bool enable = true);
@@ -41,9 +39,9 @@ Q_SIGNALS:
 
 public:
     class Private;
+
 private:
-    kdtools::pimpl_ptr<Private> d;
+    const std::unique_ptr<Private> d;
 };
 
 }
-
