@@ -1,5 +1,5 @@
 /* -*- mode: c++; c-basic-offset:4 -*-
-    uiserver/decryptverifycommand.h
+    uiserver/decryptverifycommandemailbase.h
 
     This file is part of Kleopatra, the KDE keymanager
     SPDX-FileCopyrightText: 2008 Klarälvdalens Datakonsult AB
@@ -11,9 +11,10 @@
 
 #include "assuancommand.h"
 
-#include <utils/pimpl_ptr.h>
 #include <utils/types.h>
 
+#include <memory>
+
 namespace Kleo
 {
 
@@ -43,7 +44,7 @@ public:
     class Private;
 
 private:
-    kdtools::pimpl_ptr<Private> d;
+    const std::unique_ptr<Private> d;
 };
 
 class DecryptVerifyCommand : public AssuanCommandMixin<DecryptVerifyCommand, DecryptVerifyCommandEMailBase>
