@@ -11,20 +11,20 @@
 #include "userinfo.h"
 
 // Needed for global defines
-#include <QtGlobal>
+#include <QtSystemDetection>
 
 #ifdef Q_OS_WIN
 #include "userinfo_win_p.h"
 #endif
 
-#include <KEmailAddress>
 #include <KEMailSettings>
+#include <KEmailAddress>
 
 namespace
 {
 enum UserInfoDetail {
     UserInfoName,
-    UserInfoEmailAddress
+    UserInfoEmailAddress,
 };
 
 static QString env_get_user_name(UserInfoDetail detail)
@@ -32,12 +32,12 @@ static QString env_get_user_name(UserInfoDetail detail)
     const auto var = qEnvironmentVariable("EMAIL");
     if (!var.isEmpty()) {
         QString name, addrspec, comment;
-        const auto result = KEmailAddress::splitAddress (var, name, addrspec, comment);
+        const auto result = KEmailAddress::splitAddress(var, name, addrspec, comment);
         if (result == KEmailAddress::AddressOk) {
             return (detail == UserInfoEmailAddress ? addrspec : name);
         }
     }
-    return QString ();
+    return QString();
 }
 }
 
