@@ -30,8 +30,10 @@
 
 #include "kleopatra_debug.h"
 #include <QAction>
+#include <QClipboard>
 #include <QContextMenuEvent>
 #include <QEvent>
+#include <QGuiApplication>
 #include <QHeaderView>
 #include <QItemSelection>
 #include <QItemSelectionModel>
@@ -42,6 +44,8 @@
 
 #include <KLocalizedString>
 #include <KSharedConfig>
+#include <KStandardAction>
+#include <qnamespace.h>
 
 static int tagsColumn;
 
@@ -116,6 +120,7 @@ KeyTreeView::KeyTreeView(QWidget *parent)
     , m_stringFilter()
     , m_keyFilter()
     , m_isHierarchical(true)
+    , m_showDefaultContextMenu(true)
 {
     init();
 }
@@ -131,6 +136,7 @@ KeyTreeView::KeyTreeView(const KeyTreeView &other)
     , m_keyFilter(other.m_keyFilter)
     , m_group(other.m_group)
     , m_isHierarchical(other.m_isHierarchical)
+    , m_showDefaultContextMenu(other.m_showDefaultContextMenu)
 {
     init();
     setColumnSizes(other.columnSizes());
@@ -141,7 +147,8 @@ KeyTreeView::KeyTreeView(const QString &text,
                          const std::shared_ptr<KeyFilter> &kf,
                          AbstractKeyListSortFilterProxyModel *proxy,
                          QWidget *parent,
-                         const KConfigGroup &group)
+                         const KConfigGroup &group,
+                         Options options)
     : QWidget(parent)
     , m_proxy(new KeyListSortFilterProxyModel(this))
     , m_additionalProxy(proxy)
@@ -153,6 +160,7 @@ KeyTreeView::KeyTreeView(const QString &text,
     , m_group(group)
     , m_isHierarchical(true)
     , m_onceResized(false)
+    , m_showDefaultContextMenu(!(options & Option::NoDefaultContextMenu))
 {
     init();
 }
@@ -226,8 +234,8 @@ void KeyTreeView::restoreLayout(const KConfigGroup &group)
 
 void KeyTreeView::init()
 {
-    KDAB_SET_OBJECT_NAME(m_proxy);
-    KDAB_SET_OBJECT_NAME(m_view);
+    Q_SET_OBJECT_NAME(m_proxy);
+    Q_SET_OBJECT_NAME(m_view);
 
     if (m_group.isValid()) {
         // Reopen as non const
@@ -236,15 +244,15 @@ void KeyTreeView::init()
     }
 
     if (m_additionalProxy && m_additionalProxy->objectName().isEmpty()) {
-        KDAB_SET_OBJECT_NAME(m_additionalProxy);
+        Q_SET_OBJECT_NAME(m_additionalProxy);
     }
     QLayout *layout = new QVBoxLayout(this);
-    KDAB_SET_OBJECT_NAME(layout);
+    Q_SET_OBJECT_NAME(layout);
     layout->setContentsMargins(0, 0, 0, 0);
     layout->addWidget(m_view);
 
     auto headerView = new HeaderView(Qt::Horizontal);
-    KDAB_SET_OBJECT_NAME(headerView);
+    Q_SET_OBJECT_NAME(headerView);
     headerView->installEventFilter(m_view);
     headerView->setSectionsMovable(true);
     m_view->setHeader(headerView);
@@ -258,6 +266,21 @@ void KeyTreeView::init()
     // we show details on double-click
     m_view->setExpandsOnDoubleClick(false);
 
+    if (m_showDefaultContextMenu) {
+        m_view->setContextMenuPolicy(Qt::CustomContextMenu);
+        connect(m_view, &KeyTreeView::customContextMenuRequested, this, [this](const auto &pos) {
+            auto menu = new QMenu;
+            menu->setAttribute(Qt::WA_DeleteOnClose, true);
+            menu->addAction(KStandardAction::copy(
+                this,
+                [this]() {
+                    QGuiApplication::clipboard()->setText(m_view->currentIndex().data(KeyList::ClipboardRole).toString());
+                },
+                this));
+            menu->popup(m_view->mapToGlobal(pos));
+        });
+    }
+
     if (model()) {
         if (m_additionalProxy) {
             m_additionalProxy->setSourceModel(model());
@@ -272,7 +295,7 @@ void KeyTreeView::init()
         }
     }
 
-    m_proxy->setFilterRegularExpression(QRegularExpression::escape(m_stringFilter));
+    m_proxy->setFilterRegularExpression(QRegularExpression::escape(m_stringFilter.trimmed()));
     m_proxy->setKeyFilter(m_keyFilter);
     m_proxy->setSortCaseSensitivity(Qt::CaseInsensitive);
 
@@ -452,7 +475,7 @@ void KeyTreeView::setStringFilter(const QString &filter)
         return;
     }
     m_stringFilter = filter;
-    m_proxy->setFilterRegularExpression(QRegularExpression::escape(filter));
+    m_proxy->setFilterRegularExpression(QRegularExpression::escape(filter.trimmed()));
     Q_EMIT stringFilterChanged(filter);
 }
 
@@ -664,4 +687,12 @@ void KeyTreeView::restoreStateAfterModelChange()
     initializeColumnSizes();
 }
 
+void KeyTreeView::keyPressEvent(QKeyEvent *event)
+{
+    if (event == QKeySequence::Copy) {
+        QGuiApplication::clipboard()->setText(view()->currentIndex().data(KeyList::ClipboardRole).toString());
+        event->accept();
+    }
+}
+
 #include "moc_keytreeview.cpp"
